@@ -154,12 +154,14 @@ macro_rules! scalar_internal {
             fn create_type_info(
                 registry: &mut $crate::registry::Registry,
             ) -> ::std::string::String {
-                registry.create_input_type::<$ty, _>(|_| $crate::registry::MetaType::Scalar {
-                    name: ::std::borrow::ToOwned::to_owned($name),
-                    description: $desc,
-                    is_valid: |value| <$ty as $crate::ScalarType>::is_valid(value),
-                    visible: ::std::option::Option::None,
-                    specified_by_url: $specified_by_url,
+                registry.create_input_type::<$ty, _>($crate::registry::MetaTypeId::Scalar, |_| {
+                    $crate::registry::MetaType::Scalar {
+                        name: ::std::borrow::ToOwned::to_owned($name),
+                        description: $desc,
+                        is_valid: |value| <$ty as $crate::ScalarType>::is_valid(value),
+                        visible: ::std::option::Option::None,
+                        specified_by_url: $specified_by_url,
+                    }
                 })
             }
 
@@ -187,12 +189,14 @@ macro_rules! scalar_internal {
             fn create_type_info(
                 registry: &mut $crate::registry::Registry,
             ) -> ::std::string::String {
-                registry.create_output_type::<$ty, _>(|_| $crate::registry::MetaType::Scalar {
-                    name: ::std::borrow::ToOwned::to_owned($name),
-                    description: $desc,
-                    is_valid: |value| <$ty as $crate::ScalarType>::is_valid(value),
-                    visible: ::std::option::Option::None,
-                    specified_by_url: $specified_by_url,
+                registry.create_output_type::<$ty, _>($crate::registry::MetaTypeId::Scalar, |_| {
+                    $crate::registry::MetaType::Scalar {
+                        name: ::std::borrow::ToOwned::to_owned($name),
+                        description: $desc,
+                        is_valid: |value| <$ty as $crate::ScalarType>::is_valid(value),
+                        visible: ::std::option::Option::None,
+                        specified_by_url: $specified_by_url,
+                    }
                 })
             }
 
