@@ -425,3 +425,46 @@ pub async fn test_subscription_fieldresult() {
 
     assert!(stream.next().await.is_none());
 }
+
+#[tokio::test]
+pub async fn test_oneof_field() {
+    #[derive(OneofObject)]
+    enum TestArg {
+        A(i32),
+        B(String),
+    }
+
+    struct Subscription;
+
+    #[Subscription]
+    impl Subscription {
+        #[graphql(oneof)]
+        async fn test(&self, arg: TestArg) -> impl Stream<Item = String> {
+            let value = match arg {
+                TestArg::A(a) => format!("a:{}", a),
+                TestArg::B(b) => format!("b:{}", b),
+            };
+            futures_util::stream::once(async move { value })
+        }
+    }
+
+    let schema = Schema::new(Query, EmptyMutation, Subscription);
+
+    let mut stream = schema.execute_stream(r#"subscription { test(a: 10) }"#);
+    assert_eq!(
+        Response::new(value!({
+            "test": "a:10"
+        })),
+        stream.next().await.unwrap()
+    );
+    assert!(stream.next().await.is_none());
+
+    let mut stream = schema.execute_stream(r#"subscription { test(b: "abc") }"#);
+    assert_eq!(
+        Response::new(value!({
+            "test": "b:abc"
+        })),
+        stream.next().await.unwrap()
+    );
+    assert!(stream.next().await.is_none());
+}
