@@ -789,3 +789,103 @@ pub async fn test_list_both_max_items_and_max_length() {
         })
     );
 }
+
+#[tokio::test]
+pub async fn test_custom_validator_on_oneof_field() {
+    struct MyValidator;
+
+    impl CustomValidator<TestArg> for MyValidator {
+        fn check(&self, value: &TestArg) -> Result<(), String> {
+            match value {
+                TestArg::A(a) => {
+                    if *a < 100 {
+                        Ok(())
+                    } else {
+                        Err("invalid a".into())
+                    }
+                }
+                TestArg::B(b) => {
+                    if b.len() < 5 {
+                        Ok(())
+                    } else {
+                        Err("invalid b".into())
+                    }
+                }
+            }
+        }
+    }
+
+    #[derive(OneofObject)]
+    enum TestArg {
+        A(i32),
+        B(String),
+    }
+
+    struct Query;
+
+    #[Object]
+    impl Query {
+        #[graphql(oneof)]
+        async fn test(&self, #[graphql(validator(custom = "MyValidator"))] arg: TestArg) -> String {
+            match arg {
+                TestArg::A(a) => format!("a:{}", a),
+                TestArg::B(b) => format!("b:{}", b),
+            }
+        }
+    }
+
+    let schema = Schema::new(Query, EmptyMutation, EmptySubscription);
+    assert_eq!(
+        schema
+            .execute("{ test(a: 10) }")
+            .await
+            .into_result()
+            .unwrap()
+            .data,
+        value!({
+            "test": "a:10"
+        })
+    );
+
+    assert_eq!(
+        schema
+            .execute("{ test(a: 200) }")
+            .await
+            .into_result()
+            .unwrap_err(),
+        vec![ServerError {
+            message: r#"Failed to parse "TestArg": invalid a"#.to_string(),
+            source: None,
+            locations: vec![Pos { column: 3, line: 1 }],
+            path: vec![PathSegment::Field("test".to_string())],
+            extensions: None
+        }]
+    );
+
+    assert_eq!(
+        schema
+            .execute(r#"{ test(b: "abcd") }"#)
+            .await
+            .into_result()
+            .unwrap()
+            .data,
+        value!({
+            "test": "b:abcd"
+        })
+    );
+
+    assert_eq!(
+        schema
+            .execute(r#"{ test(b: "abcde") }"#)
+            .await
+            .into_result()
+            .unwrap_err(),
+        vec![ServerError {
+            message: r#"Failed to parse "TestArg": invalid b"#.to_string(),
+            source: None,
+            locations: vec![Pos { column: 3, line: 1 }],
+            path: vec![PathSegment::Field("test".to_string())],
+            extensions: None
+        }]
+    );
+}
